==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Vigtig gruppe:</b> Det anbefales kraftigt at vælge et nøgleord til denne gruppe.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratorer af webstedet',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktører',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'besøgende på det offentlige websted når de sender meddelelse til et forum',

	// I
	'icone_creation_groupe_mots' => 'Opret ny nøgleordsgruppe',
	'icone_creation_mots_cles' => 'Opret nyt nøgleord',
	'icone_modif_groupe_mots' => 'Ret denne nøgleordsgruppe',
	'icone_mots_cles' => 'Nøgleord',
	'icone_supprimer_groupe_mots' => 'Slet denne gruppe',
	'icone_voir_tous_mots_cles' => 'Vis alle nøgleord',
	'info_articles_lies_mot' => 'Artikler knyttet til dette nøgleord',
	'info_changer_nom_groupe' => 'Ret navnet på denne gruppe:',
	'info_creation_mots_cles' => 'Opret og konfigurer webstedets nøgleord her',
	'info_dans_groupe' => 'I gruppe:',
	'info_delet_mots_cles' => 'Du har ønsket at slette nøgleordet
	<b>@titre_mot@</b> (@type_mot@). Da nøgleordet er knyttet til 
	<b>@texte_lie@</b>skal du bekræfte sletningen:', # MODIF
	'info_groupe_important' => 'vigtig gruppe',
	'info_mots_cles' => 'Nøgleord',
	'info_mots_cles_association' => 'Nøgleord i denne gruppe kan forbindes med:',
	'info_oui_suppression_mot_cle' => 'Jeg ønsker at slette dette nøgleord permanent.',
	'info_question_mots_cles' => 'Ønsker du at bruge nøgleord på webstedet?',
	'info_qui_attribue_mot_cle' => 'Nøgleord i denne grupe kan tildeles efter:',
	'info_retirer_mot' => 'Slet dette nøgleord',
	'info_retirer_mots' => 'Slet alle nøgleord',
	'info_rubriques_liees_mot' => 'Afsnit knyttet til dette nøgleord',
	'info_selection_un_seul_mot_cle' => 'Du kan <b>kun vælge et nøgleord</b> ad gangen i denne gruppe.', # MODIF
	'info_supprimer_mot' => 'slet dette nøgleord',
	'info_titre_mot_cle' => 'Navn eller titel på dette nøgleord',
	'info_un_mot' => 'Et nøgleord ad gangen',
	'item_ajout_mots_cles' => 'Tillad at knytte nøgleord til forummer',
	'item_non_ajout_mots_cles' => 'Tillad ikke at knytte nøgleord til forummer',
	'item_non_utiliser_config_groupe_mots_cles' => 'Undlad at anvende avanceret konfigurering af nøgleordsgrupper',
	'item_non_utiliser_mots_cles' => 'Benyt ikke nøgleord',
	'item_utiliser_config_groupe_mots_cles' => 'Benyt avanceret konfigurering af nøgleordsgrupper',
	'item_utiliser_mots_cles' => 'Benyt nøgleord',

	// L
	'logo_mot_cle' => 'LOGO TIL NØGLEORDET',

	// T
	'texte_config_groupe_mots_cles' => 'Ønsker du at aktivere den avancerede konfiguration af nøgleordsgrupper, ved f.eks. at specificere
			 at et entydigt ord pr. gruppe kan vælges, at en gruppe er vigtig...?', # MODIF
	'texte_mots_cles' => 'Nøgleord gør det muligt for dig at oprette emnemæssige forbindelser mellem artikler uafhængigt af, hvilket afsnit de tilhører.
		På denne måde kan du forbedre navigationen på dit websted 
		eller benytte disse egenskaber til at tilpasse artiklerne i dine skabeloner.',
	'texte_mots_cles_dans_forum' => 'Vil du tillade brug af nøgleord, som brugerne kan vælge, i de offentlige forummer på webstedet? (Advarsel: denne facilitet er temmelig vanskelig at bruge rigtigt.)',
	'texte_nouveau_mot' => 'Nyt nøgleord',
	'titre_config_groupe_mots_cles' => 'Konfiguration af nøgleordsgrupper',
	'titre_gauche_mots_edit' => 'NØGLEORDSNUMMER:',
	'titre_mots_cles_dans_forum' => 'Nøgleord i forummer på det offentlige websted',
	'titre_mots_tous' => 'Nøgleord',
	'titre_nouveau_groupe' => 'Nyhedsgruppe',
	'titre_page_mots_tous' => 'Nøgleord'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=da
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Vigtig gruppe:</b> Det anbefales kraftigt at vælge et nøgleord til denne gruppe.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'administratorer af webstedet',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktører',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'besøgende på det offentlige websted når de sender meddelelse til et forum',

	// I
	'icone_creation_groupe_mots' => 'Opret ny nøgleordsgruppe',
	'icone_creation_mots_cles' => 'Opret nyt nøgleord',
	'icone_modif_groupe_mots' => 'Ret denne nøgleordsgruppe',
	'icone_mots_cles' => 'Nøgleord',
	'icone_supprimer_groupe_mots' => 'Slet denne gruppe',
	'icone_voir_tous_mots_cles' => 'Vis alle nøgleord',
	'info_articles_lies_mot' => 'Artikler knyttet til dette nøgleord',
	'info_changer_nom_groupe' => 'Ret navnet på denne gruppe:',
	'info_creation_mots_cles' => 'Opret og konfigurer webstedets nøgleord her',
	'info_dans_groupe' => 'I gruppe:',
	'info_delet_mots_cles' => 'Du har ønsket at slette nøgleordet
	<b>@titre_mot@</b> (@type_mot@). Da nøgleordet er knyttet til 
	<b>@texte_lie@</b>skal du bekræfte sletningen:', # MODIF
	'info_groupe_important' => 'vigtig gruppe',
	'info_mots_cles' => 'Nøgleord',
	'info_mots_cles_association' => 'Nøgleord i denne gruppe kan forbindes med:',
	'info_oui_suppression_mot_cle' => 'Jeg ønsker at slette dette nøgleord permanent.',
	'info_question_mots_cles' => 'Ønsker du at bruge nøgleord på webstedet?',
	'info_qui_attribue_mot_cle' => 'Nøgleord i denne grupe kan tildeles efter:',
	'info_retirer_mot' => 'Slet dette nøgleord',
	'info_retirer_mots' => 'Slet alle nøgleord',
	'info_rubriques_liees_mot' => 'Afsnit knyttet til dette nøgleord',
	'info_selection_un_seul_mot_cle' => 'Du kan <b>kun vælge et nøgleord</b> ad gangen i denne gruppe.', # MODIF
	'info_supprimer_mot' => 'slet dette nøgleord',
	'info_titre_mot_cle' => 'Navn eller titel på dette nøgleord',
	'info_un_mot' => 'Et nøgleord ad gangen',
	'item_ajout_mots_cles' => 'Tillad at knytte nøgleord til forummer',
	'item_non_ajout_mots_cles' => 'Tillad ikke at knytte nøgleord til forummer',
	'item_non_utiliser_config_groupe_mots_cles' => 'Undlad at anvende avanceret konfigurering af nøgleordsgrupper',
	'item_non_utiliser_mots_cles' => 'Benyt ikke nøgleord',
	'item_utiliser_config_groupe_mots_cles' => 'Benyt avanceret konfigurering af nøgleordsgrupper',
	'item_utiliser_mots_cles' => 'Benyt nøgleord',

	// L
	'logo_mot_cle' => 'LOGO TIL NØGLEORDET',

	// T
	'texte_config_groupe_mots_cles' => 'Ønsker du at aktivere den avancerede konfiguration af nøgleordsgrupper, ved f.eks. at specificere
			 at et entydigt ord pr. gruppe kan vælges, at en gruppe er vigtig...?', # MODIF
	'texte_mots_cles' => 'Nøgleord gør det muligt for dig at oprette emnemæssige forbindelser mellem artikler uafhængigt af, hvilket afsnit de tilhører.
		På denne måde kan du forbedre navigationen på dit websted 
		eller benytte disse egenskaber til at tilpasse artiklerne i dine skabeloner.',
	'texte_mots_cles_dans_forum' => 'Vil du tillade brug af nøgleord, som brugerne kan vælge, i de offentlige forummer på webstedet? (Advarsel: denne facilitet er temmelig vanskelig at bruge rigtigt.)',
	'texte_nouveau_mot' => 'Nyt nøgleord',
	'titre_config_groupe_mots_cles' => 'Konfiguration af nøgleordsgrupper',
	'titre_gauche_mots_edit' => 'NØGLEORDSNUMMER:',
	'titre_mots_cles_dans_forum' => 'Nøgleord i forummer på det offentlige websted',
	'titre_mots_tous' => 'Nøgleord',
	'titre_nouveau_groupe' => 'Nyhedsgruppe',
	'titre_page_mots_tous' => 'Nøgleord',
];
